import request from '@/utils/request'

// 查询机构绑定列表
export function listBindUo(query) {
  return request({
    url: '/system/bindUO/list',
    method: 'get',
    params: query
  })
}

// 所有机构信息
export function orgDateList() {
  return request({
    url: '/system/bindUO/orgDateList',
    method: 'get'
  })
}

// 查询机构绑定详细
export function getBindUo(uoId) {
  return request({
    url: '/system/bindUO/' + uoId,
    method: 'get'
  })
}

// 新增机构绑定
export function addBindUo(data) {
  return request({
    url: '/system/bindUO',
    method: 'post',
    data: data
  })
}

// 修改机构绑定
export function updateBindUo(data) {
  return request({
    url: '/system/bindUO',
    method: 'put',
    data: data
  })
}

// 删除机构绑定
export function delBindUo(BindUoId) {
  return request({
    url: '/system/bindUO/' + BindUoId,
    method: 'delete'
  })
}

// 导出机构绑定
export function exportBindUo(query) {
  return request({
    url: '/system/bindUO/export',
    method: 'get',
    params: query
  })
}
