<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch">
      <el-form-item label="用户编号" prop="loginName">
        <el-input
          v-model="queryParams.loginName"
          placeholder="请输入用户编号"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="机构" prop="organizationCode">
        <el-select
          v-model="queryParams.organizationCode"
          placeholder="请输入设备编号"
          clearable
          size="small"
          @change.enter.native="handleQuery"
        >
          <el-option v-for="i in OrgList" :value="i.deptCode" :key="i.depId" :label="i.deptName"/>
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['deviceBindUo:BindUo:add']"
        >新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['deviceBindUo:BindUo:edit']"
        >修改
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['deviceBindUo:BindUo:remove']"
        >删除
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          :loading="exportLoading"
          @click="handleExport"
          v-hasPermi="['deviceBindUo:BindUo:export']"
        >导出
        </el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="BindUoList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center"/>
      <el-table-column label="关系id" align="center" prop="uoId" v-if="false"/>
      <el-table-column label="用户编号" align="center" prop="loginName"/>
      <el-table-column label="机构编号" align="center" prop="organizationCode"/>
      <el-table-column label="用户类型" align="center" prop="userType"/>
      <el-table-column label="账户积分" align="center" prop="integral"/>
      <el-table-column label="记账额度" align="center" prop="quota"/>
      <el-table-column label="押金" align="center" prop="deposit"/>
      <el-table-column label="有效日期" align="center" prop="effectTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.effectTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="机构" align="center" prop="jgid" v-if="false"/>
      <el-table-column label="是否删除" align="center" prop="isDelete" v-if="false"/>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['deviceBindUo:BindUo:edit']"
          >修改
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['deviceBindUo:BindUo:remove']"
          >删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改机构绑定对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="600px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules">
        <el-form-item label="用户编号" prop="loginName">
          <el-select v-model="form.loginName" placeholder="请选择用户" filterable>
            <el-option
              v-for="item in userList"
              :key="item.userName"
              :label="item.nickName"
              :value="item.userName"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="机构" prop="organizationCode">
          <el-select
            v-model="form.organizationCode"
            placeholder="请输入设备编号"
            clearable
            size="small"
            @change.enter.native="handleQuery"
          >
            <el-option v-for="i in OrgList" :value="i.deptCode" :key="i.depId" :label="i.deptName"/>
          </el-select>
        </el-form-item>
        <el-form-item label="用户类型" prop="userType">
          <el-select  v-model="form.userType" >
            <el-option
              v-for="dict in dict.type.user_type"
              :key="dict.value"
              :label="dict.label"
              :value="dict.value"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="有效时间" prop="effectTime">
          <el-date-picker clearable size="small"
                          v-model="form.effectTime"
                          type="date"
                          value-format="yyyy-MM-dd"
                          placeholder="选择有效时间">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="机构代码" prop="jgid" v-if="false">
          <el-input v-model="form.jgid" placeholder="请输入机构代码"/>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listBindUo,
  orgDateList,
  getBindUo,
  delBindUo,
  addBindUo,
  updateBindUo,
  exportBindUo
} from '@/api/system/bindUo'
import user from '@/store/modules/user'
import { getUserOrganization } from '@/api/system/user'

export default {
  name: 'deviceBindUo',
  dicts: ['user_type'],
  data() {
    return {
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 机构绑定表格数据
      BindUoList: [],
      OrgList: [],
      // 弹出层标题
      title: '',
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        loginName: null,
        userType: null,
        organizationCode: null,
        jgid: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        loginName: [
          { required: true, message: '用户编号不能为空', trigger: 'blur' }
        ],
        organizationCode: [
          { required: true, message: '机构不能为空', trigger: 'blur' }
        ],
        userType: [
          { required: true, message: "用户类型不能为空", trigger: "blur" },
        ],
        effectiveDate: [
          { required: true, message: "有效日期不能为空", trigger: "blur" },
        ]
      },
      deviceList: [],
      userList: []
    }
  },
  created() {
    this.getList()
    this.getOrgDateList()
    this.getUserList()
  },
  methods: {
    /** 查询绑定1列表 */
    getList() {
      this.loading = true
      this.queryParams.jgid = user.state.organ
      listBindUo(this.queryParams).then(response => {
        this.BindUoList = response.rows
        this.total = response.total
        this.loading = false
      })
    },
    getOrgDateList() {
      orgDateList().then(re => {
        if (re.code === 200) {
          this.OrgList = re.data
          console.log(re.data)
        }
      })
    },
    getUserList() {
      getUserOrganization({ organizationCode: user.state.organ }).then(response => {
        this.userList = response.data
      })
    },
    // 取消按钮
    cancel() {
      this.open = false
      this.reset()
    },
    // 表单重置
    reset() {
      this.form = {
        uoId: null,
        loginName: null,
        organizationCode: null,
        effectTime: null,
        jgid: null,
        isDelete: null
      }
      this.resetForm('form')
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1
      this.getList()
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm('queryForm')
      this.handleQuery()
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.uoId)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset()
      this.open = true
      this.title = '添加机构绑定'
      this.form.jgid = user.state.organ
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset()
      const uoId = row.id || this.ids
      getBindUo(uoId).then(response => {
        this.form = response.data
        this.open = true
        this.title = '修改机构绑定'
      })
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs['form'].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateBindUo(this.form).then(response => {
              this.$modal.msgSuccess('修改成功')
              this.open = false
              this.getList()
            })
          } else {
            addBindUo(this.form).then(response => {
              this.$modal.msgSuccess('新增成功')
              this.open = false
              this.getList()
            })
          }
        }
      })
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const uoIds = row.uoId || this.ids
      this.$modal.confirm('是否确认删除机构绑定编号为"' + uoIds + '"的数据项？').then(function() {
        return delBindUo(uoIds)
      }).then(() => {
        this.getList()
        this.$modal.msgSuccess('删除成功')
      }).catch(() => {
      })
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams
      this.$modal.confirm('是否确认导出所有机构绑定数据项？').then(() => {
        this.exportLoading = true
        return exportBindUo(queryParams)
      }).then(response => {
        this.$download.name(response.msg)
        this.exportLoading = false
      }).catch(() => {
      })
    }
  }
}
</script>
